@@ -31,4 +31,8 @@ class IHelpCode(Interface):
     # The unique ID of the preferences node that contains the other values for
     # this object
     preferences_path = Str
+    
+    # The code to execute. This is executed when filename is None or an empty 
+    # string.
+    code = Str
     
\ No newline at end of file
