@@ -30,19 +30,19 @@ from enthought.pyface.api import AboutDialog, DirectoryDialog, FileDialog, \
     ImageResource, OK
 from enthought.pyface.action.api import Group as ActionGroup
 from enthought.traits.api import HasTraits, Str, Property, Bool, List, \
-    Instance, Dict, Int, Any, Event, Enum, File
-from enthought.traits.ui.api import View, Group, Item, Handler, \
-    TabularEditor, ListEditor, FileEditor, TextEditor, CodeEditor
+    Instance, Dict, Int, Any, Event, Enum, on_trait_change
+from enthought.traits.ui.api import View, Group, Item, \
+    TabularEditor, ListEditor, TextEditor, CodeEditor, InstanceEditor
 from enthought.traits.ui.extras.saving import SaveHandler
 from enthought.traits.ui.key_bindings import KeyBinding, KeyBindings
 from enthought.traits.ui.menu import Action, Menu, MenuBar
-from enthought.traits.ui.table_column import ObjectColumn
 from enthought.traits.ui.tabular_adapter import TabularAdapter
 
 # Local imports
-from rest_editor_model import DocUtilsWarning, ReSTHTMLPair
+from rest_editor_model import ReSTHTMLPair
+from file_tree import FileTree
 
-# Platform dependent imports
+# Platform and toolkit dependent imports
 import platform
 if platform.system() == 'Windows' and ETSConfig.toolkit == 'wx':
     from enthought.traits.ui.wx.extra.windows.ie_html_editor import \
@@ -50,6 +50,14 @@ if platform.system() == 'Windows' and ETSConfig.toolkit == 'wx':
 else:
     from enthought.traits.ui.api import HTMLEditor
 
+if ETSConfig.toolkit == 'qt4':
+    # Qsci is not actually included in PyQt4, despite what its root package name
+    # might suggest, so we check see if it is available
+    try:
+        from PyQt4 import Qsci
+    except ImportError:
+        Qsci = None
+
 
 class DocUtilsWarningAdapter(TabularAdapter):
     columns = [('Line', 'line'), ('Description', 'description')]
@@ -69,7 +77,7 @@ class DocUtilsWarningAdapter(TabularAdapter):
 class ReSTHTMLPairHandler(SaveHandler):
 
     # SaveHandler traits
-    wildcard = 'ReST files (*.rst)|*.rst'
+    wildcard = 'ReST files (*.txt;*.rst)|*.txt;*.rst'
     extension = 'rst'
     allowValidationBypass = True
     autosave = True
@@ -121,7 +129,7 @@ class ReSTHTMLPairView(HasTraits):
         self._editor_action = True
 
     def trait_view(self, name='default'):
-        if ETSConfig.toolkit == 'wx':
+        if ETSConfig.toolkit == 'wx' or (ETSConfig.toolkit == 'qt4' and Qsci):
             rest_editor = CodeEditor(lexer='null',
                                      selected_line='selected_line',
                                      auto_scroll=True,
@@ -138,12 +146,12 @@ class ReSTHTMLPairView(HasTraits):
                                      style='custom',
                                      editor=rest_editor),
                                 Item('html',
-                                     width=200,
                                      editor=html_editor),
                                 id='rest_editor_view.PairView.HorzGroup',
                                 show_labels=False,
                                 orientation='horizontal', layout='split'),
                           Item('object.model.warnings',
+                               height=0.2,
                                editor=warning_editor),
                           id='rest_editor_view.PairView.VertGroup',
                           show_labels=False,
@@ -189,7 +197,7 @@ class ReSTHTMLPairView(HasTraits):
 class ReSTHTMLEditorHandler(SaveHandler):
 
     # SaveHandler traits
-    wildcard = 'Text files (*.rst)|*.rst'
+    wildcard = 'ReST files (*.txt;*.rst)|*.txt;*.rst'
     extension = 'rst'
     allowValidationBypass = True
 
@@ -201,10 +209,16 @@ class ReSTHTMLEditorHandler(SaveHandler):
     #-----------------------------------------------------------------
 
     def init(self, info):
-        """ Open an empty document when the editor starts.
+        """ Open an empty document if there are no empty views and set
+            selected_file to a sensible default if it is not initialized.
         """
         super(ReSTHTMLEditorHandler, self).init(info)
-        self.new(info)
+
+        if not len(info.object.open_views):
+            self.new(info)
+
+        if not info.object.selected_file:
+            info.object.selected_file = info.object.root_path
 
     def close(self, info, is_ok):
         """ Called when the user requests to close the interface. Returns a
@@ -244,31 +258,26 @@ class ReSTHTMLEditorHandler(SaveHandler):
     #  ReSTHTMLEditorHandler interface
     #-----------------------------------------------------------------
 
-    def object_selected_file_dclick_changed(self, info):
-        if os.path.isfile(info.object.selected_file):
-            self._open(info, info.object.selected_file)
-
     # File menu
 
     def new(self, info):
-        self._add_pair(info, ReSTHTMLPair())
+        info.object.new()
 
     def open(self, info):
         selected = info.object.selected_view
         if selected and selected.model.filepath:
             default_directory = os.path.dirname(selected.model.filepath)
+        elif os.path.isdir(info.object.selected_file):
+            default_directory = info.object.selected_file
         else:
-            if os.path.isdir(info.object.selected_file):
-                default_directory = info.object.selected_file
-            else:
-                default_directory = os.path.dirname(info.object.selected_file)
+            default_directory = os.path.dirname(info.object.selected_file)
 
         dialog = FileDialog(action='open', title='Open ReST File',
-                            wildcard='Text files (*.rst)|*.rst',
+                            wildcard=self.wildcard,
                             default_directory=default_directory)
         result = dialog.open()
         if result == OK and os.path.exists(dialog.path):
-            self._open(info, dialog.path)
+            info.object.open(dialog.path)
 
     def close_tab(self, info):
         view = info.object.selected_view
@@ -277,38 +286,6 @@ class ReSTHTMLEditorHandler(SaveHandler):
             self.saveObject.dirty = False
             info.object.open_views.remove(view)
 
-    def _add_pair(self, info, model):
-        """ Update the model preferences to those in the editor, then add it
-            to the views, possibly replacing an existing view.
-        """
-        model.use_sphinx = info.object.use_sphinx
-        model.sphinx_static_path = info.object.sphinx_static_path
-
-        open_views = info.object.open_views
-        if (len(open_views) and not open_views[-1].model.rest and
-            not open_views[-1].model.filepath):
-            # An empty, untitled window can be safely be replaced
-            view = open_views[-1]
-            view.model = model
-        else:
-            view = ReSTHTMLPairView(model=model)
-            open_views.append(view)
-        info.object.selected_view = view
-
-    def _open(self, info, filepath):
-        for view in info.object.open_views:
-            # If this file is already open, don't open it again
-            if filepath == view.model.filepath:
-                info.object.selected_view = view
-                return
-        fh = codecs.open(filepath, 'r', 'utf-8')
-        try:
-            pair = ReSTHTMLPair(rest=fh.read(), filepath=filepath)
-            pair.dirty = False
-            self._add_pair(info, pair)
-        finally:
-            fh.close()
-
     # Edit menu
 
     def undo(self, info): self._source_editor_action(info, 'undo')
@@ -364,9 +341,11 @@ class ReSTHTMLEditorHandler(SaveHandler):
 
 
 class ReSTHTMLEditorView(HasTraits):
+    
+    root_path = Str(USER_HOME_DIRECTORY)
+    filters = List(['*.rst', '*.txt'])
 
-    selected_file = File(USER_HOME_DIRECTORY)
-    selected_file_dclick = Event
+    selected_file = Str
 
     open_views = List(ReSTHTMLPairView)
     selected_view = Instance(ReSTHTMLPairView)
@@ -375,6 +354,8 @@ class ReSTHTMLEditorView(HasTraits):
     use_sphinx = Bool(False)
     sphinx_static_path = Str
 
+    _tree = Instance(FileTree)
+
     def __init__(self, **kw):
         super(ReSTHTMLEditorView, self).__init__(**kw)
         spec = ConfigObj()
@@ -384,6 +365,10 @@ class ReSTHTMLEditorView(HasTraits):
         self.config.validate(Validator(), copy=True)
         self.use_sphinx = self.config['use_sphinx']
 
+    #-----------------------------------------------------------------
+    #  HasTraits interface
+    #-----------------------------------------------------------------
+
     def trait_view(self, name='default'):
         file_menu = Menu(ActionGroup(Action(name='New', action='new'),
                                      Action(name='Open', action='open'),
@@ -429,15 +414,12 @@ class ReSTHTMLEditorView(HasTraits):
             KeyBinding(binding1='Ctrl-v', method_name='paste'),
             KeyBinding(binding1='Ctrl-a', method_name='select_all'))
 
-        file_editor = FileEditor(filter=['*.rst'],
-                                 dclick_name='selected_file_dclick')
-        return View(Group(Item('selected_file',
+        return View(Group(Item('_tree',
                                style='custom',
-                               width=200,
-                               editor=file_editor),
+                               width=0.25,
+                               editor=InstanceEditor()),
                           Item('open_views',
                                style='custom',
-                               width=600,
                                editor=ListEditor(use_notebook=True,
                                                  deletable=True,
                                                  dock_style='tab',
@@ -449,11 +431,70 @@ class ReSTHTMLEditorView(HasTraits):
                           show_labels=False),
                     id='vma.rest_editor_view.EditorView',
                     handler=ReSTHTMLEditorHandler(),
-                    width=800, height=600, resizable=True,
+                    width=1024, height=786, resizable=True,
                     menubar=menu_bar,
                     key_bindings=key_bindings,
                     title="reStructured Text Editor")
 
+    #-----------------------------------------------------------------
+    #  ReSTHTMLEditorView interface
+    #-----------------------------------------------------------------
+
+    def new(self, filepath=''):
+        """ Create a new document.
+        """
+        self.add_pair(ReSTHTMLPair(filepath=filepath))
+
+    def open(self, filepath):
+        """ Open the file at 'filepath'. 'filepath' is expected to a valid path.
+        """
+        # If this file is already open, don't open it again
+        for view in self.open_views:
+            if filepath == view.model.filepath:
+                self.selected_view = view
+                return
+        
+        fh = codecs.open(filepath, 'r', 'utf-8')
+        try:
+            pair = ReSTHTMLPair(rest=fh.read(), filepath=filepath)
+            pair.dirty = False
+            self.add_pair(pair)
+        finally:
+            fh.close()
+
+    def add_pair(self, model):
+        """ Update the model preferences to those in the editor, then add it
+            to the views, possibly replacing an existing view.
+        """
+        model.use_sphinx = self.use_sphinx
+        model.sphinx_static_path = self.sphinx_static_path
+
+        open_views = self.open_views
+        if (len(open_views) and not open_views[-1].model.rest and
+            not open_views[-1].model.filepath):
+            # An empty, untitled window can be safely be replaced
+            view = open_views[-1]
+            view.model = model
+        else:
+            view = ReSTHTMLPairView(model=model)
+            open_views.append(view)
+        self.selected_view = view
+
+    #-----------------------------------------------------------------
+    #  Protected interface
+    #-----------------------------------------------------------------
+        
+    def __tree_default(self):
+        return FileTree(root_path=self.root_path, filters=self.filters)
+        
+    @on_trait_change('_tree.selected')
+    def _tree_selection_changed(self):
+        self.selected_file = self._tree.selected
+
+    def _selected_file_changed(self):
+        if os.path.isfile(self.selected_file):
+            self.open(self.selected_file)
+
     def _use_sphinx_changed(self):
         self.config['use_sphinx'] = self.use_sphinx
         for view in self.open_views:
