@@ -13,3 +13,11 @@
 #------------------------------------------------------------------------------
 
 __import__('pkg_resources').declare_namespace(__name__)
+
+# For py2app / py2exe support
+try:
+    import modulefinder
+    for p in __path__:
+        modulefinder.AddPackagePath(__name__, p)
+except:
+    pass
